#
# spec file for package xmlgraphics-fop
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2000-2008, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define bname fop
Name:           xmlgraphics-fop
Version:        2.1
Release:        lp151.128.1
Summary:        Formatter for Printing XSLT Processed XML Files
License:        Apache-2.0
Group:          Productivity/Publishing/XML
URL:            https://xmlgraphics.apache.org/fop/
Source0:        https://ftp.halifax.rwth-aachen.de/apache/xmlgraphics/fop/source/fop-%{version}-src.tar.gz
#FIX-OPENSUSE: add xmlgraphics-commons to classpath
Source1:        %{name}.script
Source2:        https://svn.apache.org/repos/asf/xmlgraphics/fop/tags/fop-2_1/xmlgraphics-fop-pom-template.pom
Source3:        %{name}-fontmetrics.script
Source4:        %{name}-fontlist.script
Source5:        https://download.sourceforge.net/project/offo/offo-hyphenation/2.2/offo-hyphenation.zip
# Manpage(s)
Source10:       %{name}.xml
Source11:       %{name}-fontmetrics.xml
Source12:       %{name}-fontlist.xml
Patch1:         xmlgraphics-fop-cli.patch
Patch2:         hyphenation-more-stack.patch
Patch3:         fix-javadoc-java8.patch
Patch4:         java8-compatibility.patch
# PATCH-FEATURE-OPENSUSE reproducible-build-manifest.patch -- boo#1110024
Patch5:         reproducible-build-manifest.patch
Patch6:         fop-2.1-QDox-2.0.patch
BuildRequires:  ant >= 1.6.5
BuildRequires:  apache-pdfbox
BuildRequires:  avalon-framework >= 4.3
BuildRequires:  commons-io >= 2.4
BuildRequires:  commons-logging
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  java-devel >= 1.8
# Needed for maven conversions
BuildRequires:  javapackages-local
BuildRequires:  libxslt
BuildRequires:  qdox >= 2.0
BuildRequires:  servlet_api
BuildRequires:  unzip
BuildRequires:  xml-commons-apis >= 1.3
BuildRequires:  xmlgraphics-batik >= 1.8
BuildRequires:  xmlgraphics-commons >= 2.1
#!BuildIgnore:  saxon
Requires:       apache-pdfbox
Requires:       avalon-framework >= 4.3
Requires:       commons-io >= 2.4
Requires:       commons-logging
Requires:       java >= 1.8
Requires:       xml-commons-apis >= 1.3
Requires:       xmlgraphics-batik >= 1.8
Requires:       xmlgraphics-commons >= 2.1
Provides:       %{bname} = %{version}-%{release}
Obsoletes:      %{bname} < %{version}-%{release}
Provides:       fo-formatter = %{version}-%{release}
BuildArch:      noarch

%description
FOP (Formatting Objects Processor) is driven by XSL formatting objects
(XSL-FO). It is a Java application that reads a formatting object (FO)
tree and renders the resulting pages to one of the following output
formats: PDF (primary output target), PCL, PS, SVG, XML (area tree
representation), Print, AWT, MIF, and TXT.

%prep
%setup -q -n %{bname}-%{version} -a5
ln -thyph offo-hyphenation/hyph/*.xml
find -name "*.jar" | xargs -t rm
# Remove this file. It needs jai and we don't compile it.
# Just javadoc chokes on it.
rm src/java/org/apache/fop/util/bitmap/JAIMonochromeBitmapConverter.java
%patch1 -p1 -b .cli
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1

cp %{SOURCE2} %{SOURCE3} %{SOURCE4} .
# Replace keyword "VERSION" in XML files with the real one:
for x in %{SOURCE10} %{SOURCE11} %{SOURCE12}; do
 sed -i "s=@VERSION@=%{version}=" $x
done
sed -i "s=@version@=%{version}=" xmlgraphics-fop-pom-template.pom

%build
pushd lib
ln -s $(build-classpath avalon-framework-api)
ln -s $(build-classpath avalon-framework-impl)
ln -s $(build-classpath commons-io)
ln -s $(build-classpath commons-logging)
ln -s $(build-classpath fontbox)
ln -s $(build-classpath servlet_api)
ln -s $(build-classpath xml-commons-apis)
ln -s $(build-classpath xml-commons-apis-ext)
ln -s $(build-classpath batik-all)
ln -s $(build-classpath xmlgraphics-commons)
ln -s $(build-classpath qdox)
popd
export CLASSPATH= LANG=en_US.UTF-8
ant \
    -Djavac.source=1.8 -Djavac.target=1.8 \
	package

# Build the manpage(s) and HTML
DB=%{_datadir}/xml/docbook/stylesheet/nwalsh/current
for m in %{SOURCE10} %{SOURCE11} %{SOURCE12}; do
 xsltproc $DB/manpages/docbook.xsl $m
# Only filename for HTML is needed, remove anything before /
 xml=${m##*/}
 xsltproc --output ${xml%%.xml}.html $DB/html/docbook.xsl $m
done

%install
# jars
mkdir -p %{buildroot}%{_javadir}
install -m 644 build/%{bname}.jar %{buildroot}%{_javadir}/%{name}.jar

# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -pm 644 xmlgraphics-fop-pom-template.pom %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap

# script
mkdir -p %{buildroot}%{_bindir}
cp -p %{SOURCE1}  %{buildroot}%{_bindir}/%{name}
cp -p %{SOURCE3}  %{buildroot}%{_bindir}/%{name}-fontmetrics
cp -p %{SOURCE4}  %{buildroot}%{_bindir}/%{name}-fontlist
# compat symlink
ln -s %{name}             %{buildroot}%{_bindir}/%{bname}
ln -s %{name}-fontmetrics %{buildroot}%{_bindir}/%{bname}-fontmetrics
ln -s %{name}-fontlist    %{buildroot}%{_bindir}/%{bname}-fontlist

# data
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -pr hyph %{buildroot}%{_datadir}/%{name}
cp -pr conf %{buildroot}%{_datadir}/%{name}
install -D -m 644 conf/fop.xconf %{buildroot}%{_sysconfdir}/fop.xconf

# Manpages
mkdir -p %{buildroot}%{_mandir}/man1
for m in *.1; do
  gzip $m
done
cp -vi *.1.gz %{buildroot}%{_mandir}/man1

# Remove prefix xmlgraphics to make also the linked manpage version available
pushd %{buildroot}%{_mandir}/man1
for m in *.1.gz; do
  ln -s $m ${m#*-}
done
popd

%files
%license LICENSE
%doc NOTICE README known-issues.xml
%doc *.html

%attr(0755,root,root) %{_bindir}/%{name}
%{_bindir}/%{bname}
%attr(0755,root,root) %{_bindir}/%{name}-fontmetrics
%{_bindir}/%{bname}-fontmetrics
%attr(0755,root,root) %{_bindir}/%{name}-fontlist
%{_bindir}/%{bname}-fontlist
%{_javadir}/%{name}.jar
%{_datadir}/%{name}
%{_mavenpomdir}/*
%if %{defined _maven_repository}
%{_mavendepmapfragdir}/%{name}
%else
%{_datadir}/maven-metadata/%{name}.xml*
%endif
%{_mandir}/man1/*
%config(noreplace) %{_sysconfdir}/fop.xconf

%changelog
* Mon Jan 21 2019 Fridrich Strba <fstrba@suse.com>
- Fix build with new avalon-framework and batik
- Install maven pom file
* Fri Jan  4 2019 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * fop-2.1-QDox-2.0.patch
    + Build against QDox >= 2
* Thu Dec  6 2018 Fridrich Strba <fstrba@suse.com>
- Bring back the java-devel/java requirements to >= 1.8; we will
  fix the ByteBuffer/CharBuffer compatibilities as they arise.
- Modified patch:
  * java8-compatibility.patch
    + Fix fix ByteBuffer/CharBuffer incompatibilities with java8
  Cast all the java.nio.ByteBuffer and java.nio.CharBuffer
    instances to java.nio.Buffer before calling the clear(),
    flip(), limit(int), mark(), reset() and rewind() methods.
* Thu Nov 15 2018 thomas.schraitle@suse.com
- version 2.1
  Change requirement from java-devel-openjdk >= 1.8.0 to
  java-devel-openjdk >= 9 to avoid tracebacks because of compatibility
  issues with java.nio.Buffer, for example:
  java.lang.NoSuchMethodError:
  java.nio.CharBuffer.rewind()Ljava/nio/CharBuffer;
* Wed Nov  7 2018 Fridrich Strba <fstrba@suse.com>
- Do not depend on a particular xml-commons-apis provider.
* Mon Oct 29 2018 antoine.belvire@opensuse.org
- Add reproducible-build-manifest.patch: Remove custom "Build-Id"
  from manifests. It contains date and other information making the
  build unreproducible (boo#1110024).
* Tue Aug 28 2018 tchvatal@suse.com
- Fix building with ant >= 1.9.12
* Thu Apr  5 2018 fstrba@suse.com
- Added patch:
  * java8-compatibility.patch
    + Fix compatibility with java8 and lower when built with java9
    or higher
* Fri Sep 29 2017 fstrba@suse.com
- Don't condition the maven defines on release version, but on
  _maven_repository being defined
* Tue Sep 19 2017 fstrba@suse.com
- Fix build with jdk9: specify java source and target 1.6 and fix
  javadoc build
* Fri May 19 2017 vsistek@suse.com
- Add BuildRequires: javapackages-local (for maven conversions)
* Mon Mar  6 2017 sknorr@suse.com
- Make sure to apply new file list for Tumbleweed only
  (FATE#322405)
* Thu Mar  2 2017 fvogt@suse.com
- Add patch to fix build with stricter javadoc in version 8:
  * fix-javadoc-java8.patch (boo#1027467)
- Fix file list on SLE
* Tue Mar  8 2016 fvogt@suse.com
- Fix manpage for xmlgraphics-fop-fontmetrics
* Thu Mar  3 2016 fvogt@suse.com
- Update to fop 2.1
  - https://xmlgraphics.apache.org/fop/changes.html#version_2.1
- Remove upstreamed fop-commons-2.0.patch
    and xmlgraphics-fop-xconf.patch
- Add hyphenation-more-stack.patch to fix build with offo 2.2
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Mon Dec  8 2014 tchvatal@suse.com
- Spec-cleanify
- Do not ever run tests, we lack quite packages to do so anyway
- Drop fop-1.1-src.tar.gz.asc xmlgraphics-fop.keyring as upstream
  does not provide those anymore
- Apply patch to build with new xmlgraphics-commons:
  * fop-commons-2.0.patch
* Tue Jul  8 2014 tchvatal@suse.com
- Do not depend on ant-trax
* Thu Sep 12 2013 tchvatal@suse.com
- Drop javadoc package so we build this package
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Fri Sep  6 2013 mvyskocil@suse.com
- use new add_maven_depmap
- add missing commons packages to BuildRequires
- add gpg verification
* Thu Apr 25 2013 mvyskocil@suse.com
- fix a typo in a xmlgraphics-fop.script (bnc#817145)
* Mon Jan 28 2013 mvyskocil@suse.com
- (build) require xml-commons-apis, the org.w3c.svg are used inside fop
  part of a fix for bnc#800694
* Thu Jan 10 2013 mvyskocil@suse.com
- drop excalibur usage from all classpaths, use avalon-framework instead
* Mon Dec 17 2012 mvyskocil@suse.com
- drop excalibur-avalon from dependencies, fop now uses avalon-framework
* Sun Dec  9 2012 slavb18@gmail.com
- patched fop.xconf
  * added <auto-detect/> to pdf renderer section, so now possible to use system fonts like font-family="DejaVuSansMono"
- fix the spec file to install a (default) fop.xconf file in /etc
- patched scripts to use /etc/fop.xconf
* Tue Nov 20 2012 mvyskocil@suse.com
- add fo-formatter to provides upon a request of doc team
* Wed Nov 14 2012 slavb18@gmail.com
- fixed "Class not found" errors in fop scripts
* Thu Oct 25 2012 mvyskocil@suse.com
- add commons-logging and commons-io to Requires and fop script
- removed uneeded xalan-j2, xmlcommons and xerces from dependencies
* Wed Oct 24 2012 mvyskocil@suse.com
- update to 1.1
  * many bug fixes and a number of improvements
  * support for Complex Scripts (e.g., Arabic, Hebrew, Indic, and Southeast
  * Asian scripts)
  * http://xmlgraphics.apache.org/fop/1.1/releaseNotes_1.1.html
  * This release implements a substantial subset of the W3C
  * XSL-FO 1.1 Recommendation. For a detailed overview of FOP's compliance with
  * this recommendation, see Compliance.
  * http://xmlgraphics.apache.org/fop/compliance.html
- obsoleted xmlgraphics-fop-asf51789.patch
- obsoleted xmlgraphics-fop-build.patch
* Fri Sep  9 2011 giecrilj@stegny.2a.pl
- restored gzipped archive to avoid HTTP 404
- disabled tests (they take ages to build and they fail anyway, so do we really need them)?
- added standard hyphenation from OFFO
- told ant to use UTF-8
- fix for asf#51789
* Fri May 13 2011 toms@suse.de
- Recompressed gzip archive to bz2 to avoid warning
- Fixed non-conffile-in-etc warning for %%{_mavendepmapfragdir}
- Added new xmlgraphics-fontmetrics and xmlgraphics-fontlist scripts
  to help for better FOP configuration
- Added manpage and HTML for all scripts (xmlgraphics-fop,
  xmlgraphics-fop-fontmetrics, and xmlgraphics-fop-fontlist)
- Created links without prefix xmlgraphics-fop for
  xmlgraphics-fop-fontmetrics and xmlgraphics-fop-fontlist
- Created links for all manpages without prefix xmlgraphics-fop
* Wed May 11 2011 toms@suse.de
- Added two new scripts for creating font metrics and font lists
* Mon May  2 2011 toms@suse.de
- Fixed xmlgraphic-fop script:
  * Added excalibur/avalon-framework-impl in BASE_JAR variable to
    avoid exception in thread "main" java.lang.NoClassDefFoundError:
    org/apache/avalon/framework/configuration/DefaultConfigurationBuilder
    Caused by: java.lang.ClassNotFoundException:
    org.apache.avalon.framework.configuration.DefaultConfigurationBuilder
  * Replaced xmlgraphics-batik/util in BASE_JAR variable to
    avoid ClassNotFoundException: org.apache.batik.bridge.UserAgent
* Tue Nov 16 2010 mvyskocil@suse.cz
- correct fop Provides: Obsolete:
* Wed Nov  3 2010 mvyskocil@suse.cz
- fix bnc#650138 - fop update wanted
  * fix memory leak in property cache
  * change FONode.addCharacters() parameter to closer match the signature of the standard SAX characters() event
  * new event handling framework
  * support for font substitution
  * support for addressing all glyphs available in a Type 1 font,
    not just the ones in the font's primary encoding.
  * limited support for pages of different inline-progression-dimensions within a page-sequence.
  * minimal support for integer keep values on the various keep properties on block-level FOs.
  * new AFPGraphics2D implementation which provides the ability to use Batik to
    drive the production of AFP Graphics (GOCA) output from SVG.
  * new Resource group leveling, external streaming, and de-duplication of images and
  graphics using IncludeObject and ResourceGroup.
  * new Native image embedding support (e.g. JPEG, GIF, TIFF) using ObjectContainer
    and a MOD:CA Registry implementation.
- merge with xmlgraphics-fop-0.95-6.jpp5.src.rpm
* Thu Feb 26 2009 mvyskocil@suse.cz
- fixed bnc#467866 - fop fails if JAVACMD_OPTS is set
* Wed Aug  6 2008 skh@suse.de
- update to version 0.95, list of changes at:
  http://xmlgraphics.apache.org/fop/0.95/changes_0.95.html
- fop requires java 1.4 now
- use unversioned Requires: jre
* Fri Jun 27 2008 coolo@suse.de
- avoid build cycle between fop and saxon
* Wed Jan 30 2008 skh@suse.de
- update to version 0.94, major changes:
  * Add support for font auto-detection (JM) Thanks to Adrian Cumiskey
  * Add support for the border-collapsing model in tables (VH, JM)
  * Add support for named destinations in PDF (JB)
  * Add support for UAX#14 type line breaking (MM)
  full list of changes at:
  http://xmlgraphics.apache.org/fop/0.94/changes_0.94.html
* Tue Jul 10 2007 skh@suse.de
- update to version 0.93
- build with gcj
* Sun May  6 2007 ro@suse.de
- added unzip to buildrequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Sep 17 2004 skh@suse.de
- do no longer use setJava
* Wed Apr 28 2004 ke@suse.de
- Provide wrapper scripts for fop.sh and xalan.sh to make it find the
  java environment; reported by Thomas Schraitle; fix provided by Petr
  Mladek [#39581].
* Mon Oct 27 2003 ke@suse.de
- New package: version 0.20.5.
